@@ -18,18 +18,21 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.74 2004/12/18 21:51:47 chpe Exp $
+ *  $Id: ContentHandler.cpp,v 1.77.2.3 2005/04/17 11:12:33 chpe Exp $
  */
 
 #include "mozilla-config.h"
 
 #include "config.h"
 
+#include "ContentHandler.h"
+
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkbutton.h>
+#include <gtk/gtkmain.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
@@ -40,6 +43,7 @@
 #include <nsIMIMEInfo.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsCExternalHandlerService.h>
+#include <nsNetError.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsIServiceManager.h>
@@ -49,30 +53,36 @@
 #include "ephy-embed-single.h"
 #include "ephy-embed-shell.h"
 #include "ephy-file-chooser.h"
+#include "ephy-file-helpers.h"
 #include "ephy-stock-icons.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 #include "eel-gconf-extensions.h"
 
-#include "ContentHandler.h"
 #include "MozDownload.h"
 #include "EphyUtils.h"
 
+/* FIXME: we don't generally have a timestamp for the user action which initiated this
+ * content handler.
+ */
 #ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 GContentHandler::GContentHandler()
+: mUserTime(0)
 {
-	LOG ("GContentHandler ctor (%p)", this)
+	LOG ("GContentHandler ctor (%p)", this);
 }
 #else
-GContentHandler::GContentHandler() : mMimeType(nsnull)
+GContentHandler::GContentHandler()
+: mMimeType(nsnull)
+, mUserTime(0)
 {
-	LOG ("GContentHandler ctor (%p)", this)
+	LOG ("GContentHandler ctor (%p)", this);
 }
 #endif
 
 GContentHandler::~GContentHandler()
 {
-	LOG ("GContentHandler dtor (%p)", this)
+	LOG ("GContentHandler dtor (%p)", this);
 
 #ifndef MOZ_NSIMIMEINFO_NSACSTRING_
 	if (mMimeType)
@@ -84,15 +94,26 @@ GContentHandler::~GContentHandler()
 
 NS_IMPL_ISUPPORTS1(GContentHandler, nsIHelperAppLauncherDialog)
 
+#ifdef MOZ_NSIHELPERAPPLAUNCHERDIALOG_UNSIGNED
+/* void show (in nsIHelperAppLauncher aLauncher, in nsISupports aContext, in unsigned long aReason); */
+NS_IMETHODIMP
+GContentHandler::Show (nsIHelperAppLauncher *aLauncher,
+		       nsISupports *aContext,
+		       PRUint32 aReason)
+#else
 /* void show (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
-NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
-				    nsISupports *aContext,
-				    PRBool aForced)
+NS_IMETHODIMP
+GContentHandler::Show (nsIHelperAppLauncher *aLauncher,
+		       nsISupports *aContext,
+		       PRBool aForced)
+#endif
 {
 	nsresult rv;
 	EphyEmbedSingle *single;
 	gboolean handled = FALSE;
 
+	/* FIXME: handle aForced / aReason argument in some way? */
+
 	mContext = aContext;
 	mLauncher = aLauncher;
 	rv = Init ();
@@ -113,7 +134,11 @@ NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 	}
 	else
 	{
+#ifdef HAVE_NSICANCELABLE_H
+		mLauncher->Cancel (NS_BINDING_ABORTED);
+#else
 		mLauncher->Cancel ();
+#endif
 	}
 
 	return NS_OK;
@@ -155,6 +180,9 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 					     GTK_WINDOW (dialog));
 	}
 
+	/* FIXME: this will only be the real user time if we came from ::Show */
+	ephy_gui_window_update_user_time (GTK_WIDGET (dialog), (guint32) mUserTime);
+
 	/* FIXME: modal -- mozilla sucks! */
 	do
 	{
@@ -249,7 +277,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 			(mAction == CONTENT_ACTION_OPEN_TMP) ?
 			GTK_STOCK_OPEN : EPHY_STOCK_DOWNLOAD;
 
-	if (mPermission == EPHY_MIME_PERMISSION_UNSAFE && mHelperApp)
+	if (mPermission != EPHY_MIME_PERMISSION_SAFE && mHelperApp)
 	{
 		dialog = gtk_message_dialog_new
 			(parentWindow, GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -266,7 +294,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 	{
 		dialog = gtk_message_dialog_new
 			(parentWindow, GTK_DIALOG_DESTROY_WITH_PARENT,
-			 GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
+			 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
 			 /* translators: %s is the name of the application */
 			 _("Open this file with \"%s\"?"),
 			 mHelperApp->name);
@@ -282,7 +310,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 	{
 		dialog = gtk_message_dialog_new
 			(parentWindow, GTK_DIALOG_DESTROY_WITH_PARENT,
-			 GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
+			 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
 			 _("Download the file?"));
 		gtk_message_dialog_format_secondary_text
 			(GTK_MESSAGE_DIALOG (dialog),
@@ -311,6 +339,10 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 	g_signal_connect_data (dialog, "response",
 			       G_CALLBACK (response_cb), this,
 			       (GClosureNotify) release_cb, (GConnectFlags) 0);
+
+	/* FIXME: should find a way to get the user time of the user action which
+	 * initiated this content handler
+	 */
 	gtk_window_present (GTK_WINDOW (dialog));
 
 	return NS_OK;
@@ -326,10 +358,10 @@ NS_METHOD GContentHandler::MIMEInitiateAction (void)
 
 #ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 	mHelperApp = gnome_vfs_mime_get_default_application (mMimeType.get());
-	mPermission = ephy_embed_shell_check_mime (embed_shell, mMimeType.get());
+	mPermission = ephy_file_check_mime (mMimeType.get());
 #else
 	mHelperApp = gnome_vfs_mime_get_default_application (mMimeType);
-	mPermission = ephy_embed_shell_check_mime (embed_shell, mMimeType);
+	mPermission = ephy_file_check_mime (mMimeType);
 #endif
 
 	if (auto_downloads)
@@ -360,16 +392,30 @@ NS_METHOD GContentHandler::MIMEInitiateAction (void)
 
 NS_METHOD GContentHandler::MIMEDoAction (void)
 {
+	/* This is okay, since we either clicked on a button, or we get 0 */
+	mUserTime = gtk_get_current_event_time ();
+
 	nsCOMPtr<nsIMIMEInfo> mimeInfo;
 	mLauncher->GetMIMEInfo(getter_AddRefs(mimeInfo));
 	NS_ENSURE_TRUE (mimeInfo, NS_ERROR_FAILURE);
 
 	if (mAction == CONTENT_ACTION_OPEN)
 	{
-		nsEmbedString desc;
+		g_return_val_if_fail (mHelperApp, NS_ERROR_FAILURE);
 
-		NS_CStringToUTF16 (nsEmbedCString ("gnome-default"),
+		const char *id;
+		id = gnome_vfs_mime_application_get_desktop_id (mHelperApp);
+		
+		/* The current time is fine here as the user has just clicked
+		 * a button (it is used as the time for the application opening)
+		 */
+		char *info;
+		info = g_strdup_printf ("gnome-default:%d:%s", gtk_get_current_event_time(), id);
+
+		nsEmbedString desc;
+		NS_CStringToUTF16 (nsEmbedCString (info),
 			           NS_CSTRING_ENCODING_UTF8, desc);
+		g_free (info);
 
 		/* HACK we use the application description to ask
 		   MozDownload to open the file when download
@@ -399,7 +445,11 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	}
 	else if (mAction == CONTENT_ACTION_NONE)
 	{
+#ifdef HAVE_NSICANCELABLE_H
+		mLauncher->Cancel (NS_BINDING_ABORTED);
+#else
 		mLauncher->Cancel ();
+#endif
 	}
 	else
 	{
