@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.h,v 1.19 2004/11/02 20:56:55 chpe Exp $
+ * $Id: MozDownload.h,v 1.20.2.1 2005/04/07 11:46:32 chpe Exp $
  */
 
 #ifndef MozDownload_h__
@@ -49,7 +49,6 @@
 #include "ephy-download.h"
 #include "ephy-embed-shell.h"
 
-#include <nsIDownload.h>
 #include <nsIWebProgressListener.h>
 #include <nsIDOMDocument.h>
 #include <nsIURI.h>
@@ -59,6 +58,12 @@
 #include <nsIRequest.h>
 #include <nsIMIMEInfo.h>
 
+#ifdef HAVE_NSITRANSFER_H
+#include <nsITransfer.h>
+#else
+#include <nsIDownload.h>
+#endif
+
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 /* MozDownload
@@ -89,25 +94,42 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceUri
 				  PRInt32 aMaxSize);
 nsresult BuildDownloadPath (const char *defaultFileName, nsILocalFile **_retval);
 
-class MozDownload : public nsIDownload,
+class MozDownload :
+#ifdef HAVE_NSITRANSFER_H
+		    public nsITransfer
+#else
+		    public nsIDownload,
                     public nsIWebProgressListener
+#endif
 {
 public:
         MozDownload();
 	virtual ~MozDownload();
     
 	NS_DECL_ISUPPORTS
-	NS_DECL_NSITRANSFER
-	NS_DECL_NSIDOWNLOAD
 	NS_DECL_NSIWEBPROGRESSLISTENER
+#ifdef HAVE_NSITRANSFER_H
+	NS_DECL_NSIWEBPROGRESSLISTENER2
+#endif
+	NS_DECL_NSITRANSFER
+#ifndef HAVE_NSITRANSFER_H
+	NS_DECL_NSIDOWNLOAD
+#endif
+
+#ifdef HAVE_NSITRANSFER_H
+	nsresult GetMIMEInfo (nsIMIMEInfo **aMIMEInfo);
+	nsresult GetTargetFile (nsILocalFile **aFile);
+	nsresult GetSource(nsIURI * *aSource);
+	nsresult GetPercentComplete(PRInt32 *aPercentComplete);
+#endif
 
 	virtual void Cancel();
 	virtual void Pause();
 	virtual void Resume();
 
 	nsresult GetState           (EphyDownloadState *aDownloadState);
-	nsresult GetCurrentProgress (PRInt32 *aCurrentProgress);
-	nsresult GetTotalProgress   (PRInt32 *aTProgress);
+	nsresult GetCurrentProgress (PRInt64 *aCurrentProgress);
+	nsresult GetTotalProgress   (PRInt64 *aTProgress);
  	nsresult GetElapsedTime     (PRInt64 *aTProgress);
 	nsresult InitForEmbed       (nsIURI *aSource, nsIURI *aTarget,
 				     const PRUnichar *aDisplayName, nsIMIMEInfo *aMIMEInfo,
@@ -124,9 +146,9 @@ protected:
 	PRInt64		    	mElapsed;
 	PRInt32		    	mInterval;
 	PRInt32                 mPercentComplete;
-	PRInt32                 mTotalProgress;
-	PRInt32                 mCurrentProgress;
-	PRInt32			mMaxSize;
+	PRInt64                 mTotalProgress;
+	PRInt64                 mCurrentProgress;
+	PRInt64			mMaxSize;
 
 	nsresult                mStatus;
 
