@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-persist.cpp,v 1.44 2004/11/02 20:56:55 chpe Exp $
+ *  $Id: mozilla-embed-persist.cpp,v 1.46.2.2 2005/04/18 19:04:24 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -136,9 +136,9 @@ impl_save (EphyEmbedPersist *persist)
 	nsresult rv;
 	char *filename;
 	char *uri;
-	long max_size;
+	gint64 max_size;
 	EphyEmbed *embed;
-	EmbedPersistFlags flags;
+	EphyEmbedPersistFlags flags;
 	EphyEmbedSingle *single;
 
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
@@ -153,7 +153,7 @@ impl_save (EphyEmbedPersist *persist)
 		      "max_size", &max_size,
 		      NULL);
 
-	g_return_val_if_fail (!(flags & EMBED_PERSIST_COPY_PAGE)
+	g_return_val_if_fail (!(flags & EPHY_EMBED_PERSIST_COPY_PAGE)
 			      || embed != NULL, FALSE);	
 
 	EphyBrowser *browser = NULL;
@@ -176,6 +176,8 @@ impl_save (EphyEmbedPersist *persist)
 	if (tmp_filename == NULL) return FALSE;
 
 	nsCOMPtr<nsILocalFile> tmpFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
+	NS_ENSURE_TRUE (tmpFile, FALSE);
+
 	tmpFile->InitWithNativePath (nsEmbedCString (tmp_filename));
 	g_free (tmp_filename);
 
@@ -218,7 +220,7 @@ impl_save (EphyEmbedPersist *persist)
 	nsCOMPtr<nsIDOMDocument> DOMDocument;
 	if (!uri)
 	{		
-		if (flags & EMBED_PERSIST_MAINDOC)
+		if (flags & EPHY_EMBED_PERSIST_MAINDOC)
 		{
                 	browser->GetDocument (getter_AddRefs(DOMDocument));
 		}
@@ -241,7 +243,7 @@ impl_save (EphyEmbedPersist *persist)
 	 * the page, which will possibly give a different page than the original which we
 	 * need for view source
 	 */
-	NS_ENSURE_TRUE (!(flags & EMBED_PERSIST_COPY_PAGE) || pageDescriptor, FALSE);
+	NS_ENSURE_TRUE (!(flags & EPHY_EMBED_PERSIST_COPY_PAGE) || pageDescriptor, FALSE);
 
 	if (filename == NULL)
 	{
@@ -284,7 +286,7 @@ impl_to_string (EphyEmbedPersist *persist)
 {
 	EphyEmbed *embed;
 	nsCOMPtr<nsIDOMDocument> DOMDocument;
-	EmbedPersistFlags flags;
+	EphyEmbedPersistFlags flags;
 	EphyBrowser *browser;
 	nsresult rv = NS_OK;
 
@@ -300,7 +302,7 @@ impl_to_string (EphyEmbedPersist *persist)
 	browser = (EphyBrowser *) _mozilla_embed_get_ephy_browser (MOZILLA_EMBED(embed));
 	g_assert (browser != NULL);
 
-	if (flags & EMBED_PERSIST_MAINDOC)
+	if (flags & EPHY_EMBED_PERSIST_MAINDOC)
 	{
 		rv = browser->GetDocument (getter_AddRefs(DOMDocument));
 	}
