@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.49 2005/01/18 19:28:14 chpe Exp $
+ *  $Id: ephy-dialog.c,v 1.50 2005/01/30 20:09:58 chpe Exp $
  */
 
 #include "config.h"
@@ -82,11 +82,11 @@ struct _EphyDialogPrivate
 	GtkWidget *parent;
 	GtkWidget *dialog;
 
-	gboolean modal : 1;
-	gboolean has_default_size : 1;
-	gboolean disposing : 1;
-	gboolean initialized : 1;
-	gboolean persist_position : 1;
+	guint modal : 1;
+	guint has_default_size : 1;
+	guint disposing : 1;
+	guint initialized : 1;
+	guint persist_position : 1;
 	int default_width;
 	int default_height;
 };
