@@ -19,6 +19,11 @@ GType ephy_node_signal_type_get_type (void);
 #define EPHY_TYPE_STATE_WINDOW_FLAGS ephy_state_window_flags_get_type()
 GType ephy_state_window_flags_get_type (void);
 
+
+/* --- ephy-dbus.h --- */
+#define EPHY_TYPE_DBUS_BUS ephy_dbus_bus_get_type()
+GType ephy_dbus_bus_get_type (void);
+
 G_END_DECLS
 
 #endif /* EPHY_LIB_TYPE_BUILTINS_H */
